pub struct BringUpLedger {
pub entries: Vec<BringUpEntry>,
pub notes: Vec<String>,
}Expand description
Hardware bring-up ledger for all glasses lanes.
Fields
entries: Vec<BringUpEntry>One entry per hardware lane.
notes: Vec<String>Notes that apply to the full ledger.
Implementations
Sourceimpl BringUpLedger
impl BringUpLedger
Sourcepub fn default_glasses() -> Self
pub fn default_glasses() -> Self
Builds the hardware-free default ledger.
Sourcepub fn entry(&self, lane: &str) -> Option<&BringUpEntry>
pub fn entry(&self, lane: &str) -> Option<&BringUpEntry>
Returns the entry for lane, if the ledger contains it.
Sourcepub fn entry_mut(&mut self, lane: &str) -> Option<&mut BringUpEntry>
pub fn entry_mut(&mut self, lane: &str) -> Option<&mut BringUpEntry>
Returns the mutable entry for lane, if the ledger contains it.
Sourcepub fn enable_lane(&self, lane: &str) -> Result<()>
pub fn enable_lane(&self, lane: &str) -> Result<()>
Enables a lane only when its verified flag is true.