pub enum FocusDir {
Next,
Prev,
}Expand description
A direction to advance focus in move_focus.
Variants
Next
Advance to the next id in order, wrapping past the end to the first.
Prev
Advance to the previous id in order, wrapping past the start to the last.