preset

Function preset 

pub fn preset(name: &str) -> Option<SurfaceCaps>
Returns the baseline SurfaceCaps for a well-known preset name.

The client_id is set to the preset name and should be overridden with a real id via SurfaceCaps::from_preset. Returns None for unknown presets.