pub fn register_universal_default(registry: &mut LensRegistry, readonly: bool)Expand description
Register the universal default view and editor into registry. When
readonly is set, the universal editor renders but never commits.
pub fn register_universal_default(registry: &mut LensRegistry, readonly: bool)Register the universal default view and editor into registry. When
readonly is set, the universal editor renders but never commits.